@@ -41,6 +41,15 @@ class CalendarsQuerySet(BaseRefQuerySet):
 
 class CalendarsManager(BaseRefManager):
 
+    @staticmethod
+    def get_default():
+        try:
+            return Calendars.objects.get(props=Calendars.props.default)
+        except Calendars.DoesNotExist:
+            raise Exception('Не установлен текущий календарь.')
+        except Calendars.MultipleObjectsReturned:
+            raise Exception('Не однозначная установка текущего календаря.')
+
     @staticmethod
     def getRecord(record):
         res = {
@@ -51,6 +60,7 @@ class CalendarsManager(BaseRefManager):
             'begindate': record.begindate,
             'enddate': record.enddate,
             'description': record.description,
+            'isDefault': record.props.default.is_set,
             'props': record.props,
             'parent_id': record.parent.id if record.parent else None,
         }
