@@ -23,23 +23,48 @@ class Event:
 
         self.users = [event_type_users.user for event_type_users in Event_type_users.objects.filter(event_type=self.event_type)]
 
-    def send_message(self, message, users_array=None):
-        from isc_common.auth.http.LoginRequets import LoginRequest
-        from tracker.models.messages import MessagesManager
+    def send_message(self, message=None, users_array=None, progress=None, len=None):
         from events.models.event_type_users import Event_type_usersManager
+        from isc_common.auth.http.LoginRequets import LoginRequest
+        from isc_common.common import blinkString
+        from isc_common.progress import Progress
+        from isc_common.progress import ProgressDroped
+        from tracker.models.messages import MessagesManager
+        from isc_common.progress import progress_deleted
 
         users = self.users.copy()
 
         if isinstance(users_array, list):
             users.extend(users_array)
 
+        idx = 0
+        if isinstance(progress, Progress) and len:
+            progress.setQty(len)
+
         for user in users:
+            if isinstance(message, list):
+                _message = message[idx]
+                idx += 1
+            elif isinstance(message, str):
+                _message = message
+            else:
+                raise Exception(f'Недопустимый формат message.')
+
+            msg = f'<h3>Сообщение от:</h3> #{self.event_type.full_name}' \
+                  f'<p>{MessagesManager.get_border(_message, user)}'
+
+            if isinstance(progress, Progress):
+                progress.setContentsLabel(blinkString(f'Отправка сообщения: {msg} <p/> {user.get_full_name}', bold=True, blink=False, color='blue'))
+
+                if len:
+                    if progress.step() != 0:
+                        raise ProgressDroped(progress_deleted)
+
             LoginRequest.send_bot_message(
                 user=user,
                 bot=Event_type_usersManager.get_bot(self.event_type),
-                message=f'<h3>Сообщение от:</h3> #{self.event_type.full_name}'
-                        f'<p>{MessagesManager.get_border(message, user)}',
-                compulsory_reading=IsBitOn(self.event_type.props, 1)
+                message=msg,
+                compulsory_reading=self.event_type.props.compulsory_reading.is_set
             )
 
 
