@@ -182,6 +182,10 @@ def cleanProgresses(id_progresses=None, exclude_processes=None):
         settings.LOCKS.release(key)
 
 
+class NotImplementation(Exception):
+    def __init__(self):
+        super().__init__('Нет рееализации !!!!!!')
+
 class Stack:
 
     def __iter__(self):
@@ -286,3 +290,8 @@ def get_list_nums_key_dict(data):
         else:
             res.append(data)
     return res
+
+
+class Wrapper:
+    def __init__(self, **kwargs):
+        self.__dict__.update(kwargs)
