@@ -7,6 +7,9 @@ def getOrElse(default, value):
     else:
         return default
 
+red='red'
+blue='blue'
+green='green'
 
 def blinkString(text, blink=True, color="black", bold=False) -> Text:
     if blink:
@@ -14,7 +17,7 @@ def blinkString(text, blink=True, color="black", bold=False) -> Text:
     else:
         res = f'<div><strong><font color="{color}"</font>{text}</strong></div>'
 
-    if bold:
+    if bold == True:
         return f'<b>{res}</b>'
     else:
         return res
